#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['signalboxclient']

package_data = \
{'': ['*']}

setup(name='signalboxclient',
      version='0.1.21',
      description='A library used as a Four2/SignalBox client.',
      author='Rian Finnegan',
      author_email='rian@four2.ai',
      url='https://www.four2.ai',
      packages=packages,
      package_data=package_data,
     )
